@@ -13,12 +13,70 @@ checking.
 
 =head1 FUNCTIONS
 
+=head2 App::HWD::Task->parse( $input_line, $parent_task )
+
+Returns an App::HWD::Task object from an input line
+
 =cut
 
 use warnings;
 use strict;
 use DateTime::Format::Strptime;
 
+sub parse {
+    my $class = shift;
+    my $line = shift;
+    my $parent = shift;
+
+    my $line_regex = qr/
+        ^
+        (-+)        # leading dashes
+        \s*         # whitespace
+        (.+)        # everything else
+        $
+    /x;
+
+    if ( $line =~ $line_regex ) {
+        my $level = length $1;
+        my $name = $2;
+        my $id;
+        my $estimate;
+        my %date;
+
+        if ( $name =~ s/\s*\(([^)]+)\)\s*$// ) {
+            my $parens = $1;
+            my $parser = DateTime::Format::Strptime->new( pattern => '%Y-%m-%d' );
+
+            my @subfields = split /,/, $parens;
+            for ( @subfields ) {
+                s/^\s+//;
+                s/\s+$//;
+                /^#(\d+)$/ and $id = $1, next;
+                /^((\d*\.)?\d+)h$/  and $estimate = $1, next;
+                /^(added|deleted) (\S+)$/i and do {
+                    my ($type,$date) = ($1,$2);
+                    $date{$type} = $parser->parse_datetime($date);
+                    next if $date{$type};
+                };
+                warn qq{I don't understand "$_"\n};
+            }
+        }
+
+        my $task = $class->new( {
+            level               => $level,
+            name                => $name,
+            id                  => $id,
+            estimate            => $estimate,
+            date_added_obj      => $date{added},
+            date_deleted_obj    => $date{deleted},
+            parent              => $parent,
+        } );
+    }
+    else {
+        return;
+    }
+}
+
 =head2 App::HWD::Task->new( { args } )
 
 Creates a new task from the args passed in.  They should include at
@@ -45,79 +103,6 @@ sub new {
     return $self;
 }
 
-=head2 App::HWD::Task->parse( $input_line, $parent_task )
-
-Returns an App::HWD::Task object from an input line.
-
-=cut
-
-my $line_regex = qr/
-    ^
-    (-+|\*+)    # leading dashes or stars
-    \s*         # whitespace
-    (.+)        # everything else
-    $
-/x;
-
-sub parse {
-    my $class = shift;
-    my $line = shift;
-    my $parent = shift;
-    my $where = shift;
-
-    if ( $line =~ $line_regex ) {
-        my $level = length $1;
-        my $name = $2;
-        my $id;
-        my $estimate;
-        my @assignees;
-        my %date;
-
-        if ( $name =~ s/\s*\(([^)]+)\)\s*$// ) {
-            my $parens = $1;
-            my $parser = DateTime::Format::Strptime->new( pattern => '%Y-%m-%d' );
-
-            my @subfields = split /,/, $parens;
-            for ( @subfields ) {
-                # Strip whitespace
-                s/^\s+//;
-                s/\s+$//;
-
-                # ID?
-                /^#(\d+)$/ and $id = $1, next;
-
-                # Estimate in hours or minutes?
-                /^((\d*\.)?\d+)h$/  and $estimate = $1, next;
-                /^(\d+)m$/          and $estimate = $1/60, next;
-
-                # Add or delete dates
-                /^(added|deleted) (\S+)$/i and do {
-                    my ($type,$date) = ($1,$2);
-                    $date{$type} = $parser->parse_datetime($date);
-                    next if $date{$type};
-                };
-                # Anything else, we assume it's who's going to do it
-                push( @assignees, $_ );
-            }
-        }
-
-        my $task = $class->new( {
-            level               => $level,
-            name                => $name,
-            id                  => $id,
-            where               => $where,
-            estimate            => $estimate,
-            date_added_obj      => $date{added},
-            date_deleted_obj    => $date{deleted},
-            parent              => $parent,
-            assignees           => (@assignees ? \@assignees : undef),
-        } );
-    }
-    else {
-        return;
-    }
-}
-
 =head2 $task->level()
 
 Returns the level of the task
@@ -130,10 +115,6 @@ Returns the name of the task
 
 Returns the ID of the task, or the empty string if there isn't one.
 
-=head2 $task->where()
-
-Returns a string describing the location of the task's line, as in "line 45 of foo.hwd"
-
 =head2 $task->estimate()
 
 Returns the estimate, or 0 if it's not set.
@@ -170,18 +151,11 @@ Returns a list of child tasks.
 
 Returns the array of App::HWD::Work applied to the task.
 
-=head2 $task->assignees()
-
-Returns a list of the persons or entities assigned to do the task.
-Note that this name, or these names, may not correspond to who actually
-does the work.
-
 =cut
 
 sub level               { return shift->{level} }
 sub name                { return shift->{name} }
 sub id                  { return shift->{id} || "" }
-sub where               { return shift->{where} }
 sub estimate            { return shift->{estimate} || 0 }
 sub work                { return @{shift->{work}||[]} }
 sub notes               { return @{shift->{notes}||[]} }
@@ -189,7 +163,6 @@ sub date_added_obj      { return shift->{date_added_obj} }
 sub date_deleted_obj    { return shift->{date_added_obj} }
 sub parent              { return shift->{parent} }
 sub children            { return @{shift->{children}||[]} }
-sub assignees           { return @{shift->{assignees}||[]} }
 
 sub date_added {
     my $self = shift;
